@@ -1,6 +1,14 @@
+/*
+For general Scribus (>=1.3.2) copyright and licensing information please refer
+to the COPYING file provided with the program. Following this notice may exist
+a copyright and/or license notice that predates the release of Scribus 1.3.2
+for which a new license (GPL+exception) is in place.
+*/
 /***************************************************************************
 *   Copyright (C) 2004 by Craig Bradney                                   *
 *   cbradney@zip.com.au                                                   *
+*   Copyright (C) 2005 by Petr Vanek                                      *
+*   petr@yarpen.cz                                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
@@ -22,11 +30,11 @@
 #include "helpbrowser.moc"
 
 #include <qvariant.h>
+#include <qstring.h>
 #include <qpushbutton.h>
 #include <qtabwidget.h>
 #include <qwidget.h>
 #include <qheader.h>
-#include <qlistview.h>
 #include <qtextbrowser.h>
 #include <qlayout.h>
 #include <qtooltip.h>
@@ -45,25 +53,171 @@
 #include <qlineedit.h>
 #include <qaccel.h>
 #include <qinputdialog.h>
+#include <qmenubar.h>
+#include <qpopupmenu.h>
+#include <qprinter.h>
+#include <qpainter.h>
+#include <qpaintdevicemetrics.h>
+#include <qsimplerichtext.h>
+#include <qxml.h>
 
-#ifdef _MSC_VER
-#if (_MSC_VER >= 1200)
-#include "win-config.h"
-#endif
-#else
-#include "config.h"
+#include "scpaths.h"
+#include "util.h"
+#include "scconfig.h"
+#include "prefsmanager.h"
+#include "prefsfile.h"
+
+#if defined(_WIN32)
+#include <windows.h>
+#include <shellapi.h>
 #endif
 
 extern QPixmap loadIcon(QString nam);
 
 
+/*! \brief Returns the name of the cfg file for bookmarks.
+A helper function.
+\author Petr Vanek <petr@yarpen.cz>
+*/
+QString bookmarkFile()
+{
+	QString fname(QDir::convertSeparators(QDir::homeDirPath()+ "/.scribus/doc/bookmarks.xml"));
+	QFileInfo f(fname);
+	if (!f.exists())
+	{
+		QDir d(QDir::convertSeparators(QDir::homeDirPath()+ "/.scribus/"));
+		d.mkdir("doc");
+	}
+	return fname;
+}
+
+
+/*! \brief Returns the name of the cfg file for persistent history.
+A helper function.
+\author Petr Vanek <petr@yarpen.cz>
+*/
+QString historyFile()
+{
+	QString fname(QDir::convertSeparators(QDir::homeDirPath()+ "/.scribus/doc/history.xml"));
+	QFileInfo f(fname);
+	if (!f.exists())
+	{
+		QDir d(QDir::convertSeparators(QDir::homeDirPath()+ "/.scribus/"));
+		d.mkdir("doc");
+	}
+	return fname;
+}
+
+
+/*! \brief XML parsef for documantation bookmarks.
+This is small helper class which reads saved bookmarks configuration
+from ~/.scribus/doc/bookmarks.xml file.
+The reference to QListView *view is a reference to the list view with bookmarks
+\author Petr Vanek <petr@yarpen.cz>
+*/
+class BookmarkParser : public QXmlDefaultHandler
+{
+	public:
+		QListView* view;
+
+		bool startDocument()
+		{
+			return true;
+		}
+
+		bool startElement(const QString&, const QString&, const QString& qName, const QXmlAttributes& attrs)
+		{
+			if (qName == "item")
+			{
+				QListViewItem *item = new QListViewItem(view, attrs.value(0), attrs.value(1));
+				view->insertItem(item);
+			}
+			return true;
+		}
+
+		bool endElement(const QString&, const QString&, const QString&)
+		{
+			return true;
+		}
+};
+
+/*! \brief XML parsef for documantation history.
+This is small helper class which reads saved bookmarks configuration
+from ~/.scribus/doc/history.xml file.
+The reference to historyBrowser is a reference to the dialog.
+\author Petr Vanek <petr@yarpen.cz>
+*/
+class HistoryParser : public QXmlDefaultHandler
+{
+	public:
+		HelpBrowser *helpBrowser;
+
+		bool startDocument()
+		{
+			return true;
+		}
+
+		bool startElement(const QString&, const QString&, const QString& qName, const QXmlAttributes& attrs)
+		{
+			if (qName == "item")
+			{
+				struct histd his;
+				his.title = attrs.value(0);
+				his.url = attrs.value(1);
+				helpBrowser->mHistory[helpBrowser->histMenu->insertItem(his.title)] = his;
+			}
+			return true;
+		}
+
+		bool endElement(const QString&, const QString&, const QString&)
+		{
+			return true;
+		}
+};
+
+int HelpListItem::compare(QListViewItem *i, int col, bool asc) const
+{
+	if (col == 1)
+	{
+		int d = text(col).toInt() - i->text(col).toInt();
+		if (d > 0)
+			return 1;
+		return -1;
+	}
+	else
+		return QListViewItem::compare(i, col, asc);
+}
+
+TextBrowser::TextBrowser(QWidget * parent, const char * name) : QTextBrowser(parent, name)
+{
+}
+
+void TextBrowser::setSource(const QString &name)
+{
+#if defined(_WIN32)
+	int index = name.find( "http:/" );
+	if ( index >=0 )
+	{
+		QString url = name.right(name.length() - index);
+		//textBrowser->setSource( textBrowser->source() );
+		QT_WA( {
+		ShellExecute( winId(), 0, (TCHAR*)url.ucs2(), 0, 0, SW_SHOWNORMAL );
+	    } , {
+		ShellExecuteA( winId(), 0, url.local8Bit(), 0, 0, SW_SHOWNORMAL );
+	    } );
+		return;
+	}
+#endif
+	QTextBrowser::setSource(name);
+}
+
 HelpBrowser::HelpBrowser( QWidget* parent, QString /*caption*/, QString guiLanguage, QString jumpToSection, QString jumpToFile)
-	: QWidget( parent, "Help", WType_TopLevel | WDestructiveClose )
+	: QWidget( parent, "Help", WType_TopLevel | WDestructiveClose | WGroupLeader )
 {
 	QString fileName;
 	mHistory.clear();
 	struct histd his;
-	language = guiLanguage=="" ? QString("en") : guiLanguage.left(2);
+	language = guiLanguage.isEmpty() ? QString("en") : guiLanguage.left(2);
 	helpBrowsermainLayout = new QVBoxLayout( this);
 	buttonLayout = new QHBoxLayout;
 	buttonLayout->setSpacing( 6 );
@@ -97,16 +251,12 @@ HelpBrowser::HelpBrowser( QWidget* parent, QString /*caption*/, QString guiLangu
 	helpBrowserLayout->addWidget( splitter );
 
 	tabWidget = new QTabWidget( splitter, "tabWidget" );
-	//tabWidget = new QTabWidget( this, "tabWidget" );
-	splitter->setResizeMode(tabWidget, QSplitter::Stretch );
-	tabWidget->setSizePolicy( QSizePolicy( QSizePolicy::Maximum, QSizePolicy::Expanding, false) );
 	tabContents = new QWidget( tabWidget, "tabContents" );
 	tabLayout = new QHBoxLayout( tabContents, 11, 6, "tabLayout");
 
 	listView = new QListView( tabContents, "listView" );
 	listView->addColumn( tr( "Contents" ) );
 	listView->addColumn( tr( "Link" ) , 0 );
-//	listView->addColumn( tr( "Link" ) );
 	listView->setColumnWidthMode( 0, QListView::Maximum );
 	listView->setColumnWidthMode( 1, QListView::Manual );
 	listView->setSorting(-1,-1);
@@ -117,51 +267,96 @@ HelpBrowser::HelpBrowser( QWidget* parent, QString /*caption*/, QString guiLangu
 	tabLayout->addWidget( listView );
 
 	tabWidget->insertTab( tabContents, tr("&Contents") );
-	//helpBrowserLayout->addWidget( tabWidget );
 
 	// searching
 	tabSearching = new QWidget(tabWidget, "tabSearching");
 	searchingMainLayout = new QVBoxLayout(tabSearching, 11, 6, "searchingMainLayout");
 	searchingButtonLayout = new QHBoxLayout;
 	searchingEdit = new QLineEdit(tabSearching, "searchingEdit");
-	searchingButton = new QPushButton(tr("&Search"), tabSearching, "searchingButton");
+	searchingButton = new QPushButton( tr("&Search"), tabSearching, "searchingButton");
 	searchingButtonLayout->addWidget(searchingEdit);
 	searchingButtonLayout->addWidget(searchingButton);
 	searchingMainLayout->addLayout(searchingButtonLayout);
 	searchingView = new QListView(tabSearching, "searchingView");
-	searchingView->addColumn( tr( "Contents" ) );
-	searchingView->addColumn( tr( "Link" ) , 0 );
+	searchingView->addColumn(tr("Contents"));
+	searchingView->addColumn(tr("Relevance"));
+	searchingView->addColumn(tr("Link" ) ,0);
 	searchingView->setColumnWidthMode( 0, QListView::Maximum );
 	searchingView->setColumnWidthMode( 1, QListView::Manual );
-	searchingView->setSorting(-1,-1);
+	searchingView->setSorting(1, false);
 	searchingView->setRootIsDecorated( true );
 	searchingView->setSelectionMode(QListView::Single);
 	searchingView->setDefaultRenameAction(QListView::Reject);
+	searchingView->setAllColumnsShowFocus(true);
 	searchingView->clear();
 	searchingMainLayout->addWidget(searchingView);
-	tabWidget->insertTab(tabSearching, tr("S&earch"));
+	tabWidget->insertTab(tabSearching, tr("Se&arch"));
 
-	textBrowser = new QTextBrowser( splitter, "textBrowser" );
-	splitter->setResizeMode(textBrowser, QSplitter::Stretch);
-	//textBrowser = new QTextBrowser( this, "textBrowser" );
-	textBrowser->setSizePolicy( QSizePolicy( QSizePolicy::Ignored, QSizePolicy::Expanding, false ) );
+	// bookmarks
+	tabBookmarks = new QWidget(tabWidget, "tabBookmarks");
+	bookmarksMainLayout = new QVBoxLayout(tabBookmarks, 11, 6, "bookmarksMainLayout");
+	bookmarksView = new QListView(tabBookmarks, "bookmarksView");
+	bookmarksView->addColumn( tr( "Contents" ) );
+	bookmarksView->addColumn( tr( "Link" ) , 0 );
+	bookmarksView->setColumnWidthMode( 0, QListView::Maximum );
+	bookmarksView->setColumnWidthMode( 1, QListView::Manual );
+	bookmarksView->setSorting(1, -1);
+	bookmarksView->setRootIsDecorated( true );
+	bookmarksView->setSelectionMode(QListView::Single);
+	bookmarksView->setDefaultRenameAction(QListView::Reject);
+	bookmarksView->clear();
+	bookmarksMainLayout->addWidget(bookmarksView);
+	bookmarksButtonLayout = new QHBoxLayout;
+	bookmarkButton = new QPushButton( tr("&New"), tabBookmarks, "bookmarkButton");
+	deleteBookmarkButton = new QPushButton( tr("&Delete"), tabBookmarks, "deleteBookmarkButton");
+	deleteAllBookmarkButton = new QPushButton( tr("De&lete All"), tabBookmarks, "deleteAllBookmarkButton");
+	bookmarksButtonLayout->addWidget(bookmarkButton);
+	bookmarksButtonLayout->addWidget(deleteBookmarkButton);
+	bookmarksButtonLayout->addWidget(deleteAllBookmarkButton);
+	bookmarksMainLayout->addLayout(bookmarksButtonLayout);
+	tabWidget->insertTab(tabBookmarks, tr("Book&marks"));
+
+	textBrowser = new TextBrowser( splitter, "textBrowser" );
+	textBrowser->setSizePolicy( QSizePolicy( QSizePolicy::Maximum, QSizePolicy::Maximum, false ) );
 	textBrowser->setFrameShape( QTextBrowser::StyledPanel );
 	QMimeSourceFactory *textBrowserMSF=textBrowser->mimeSourceFactory();
 	textBrowserMSF->setExtensionType("html", "text/html;charset=UTF-8");
-	//helpBrowserLayout->addWidget( textBrowser );
 	helpBrowsermainLayout->addLayout( helpBrowserLayout );
 
+	// menus
+	menuBar = new QMenuBar(this);
+	QPopupMenu *fileMenu = new QPopupMenu(this);
+	fileMenu->insertItem(loadIcon("DateiPrint.xpm"), tr("&Print..."), this, SLOT(print()), CTRL+Key_P);
+	fileMenu->insertSeparator();
+	fileMenu->insertItem(loadIcon("exit.png"), tr("E&xit"), this, SLOT(close()));
+	menuBar->insertItem( tr("&File"), fileMenu);
+	QPopupMenu *editMenu = new QPopupMenu(this);
+	editMenu->insertItem(loadIcon("find.png"), tr("&Find..."), this, SLOT(find()), CTRL+Key_F);
+	editMenu->insertItem( tr("Find &Next"), this, SLOT(findNext()), Key_F3);
+	editMenu->insertItem( tr("Find &Previous"), this, SLOT(findPrevious()), SHIFT+Key_F3);
+	menuBar->insertItem( tr("&Edit"), editMenu);
+	QPopupMenu *bookmarkMenu = new QPopupMenu(this);
+	bookmarkMenu->insertItem( tr("&Add Bookmark"), this, SLOT(bookmarkButton_clicked()), CTRL+Key_D);
+	bookmarkMenu->insertItem( tr("&Delete"), this, SLOT(deleteBookmarkButton_clicked()));
+	bookmarkMenu->insertItem( tr("D&elete All"), this, SLOT(deleteAllBookmarkButton_clicked()));
+	helpBrowsermainLayout->setMenuBar(menuBar);
+	menuBar->insertItem( tr("&Bookmarks"), bookmarkMenu);
 	languageChange();
-	resize( QSize(602, 491).expandedTo(minimumSizeHint()) );
-	clearWState( WState_Polished );
 	loadMenu();
 	listView->header()->hide();
 	searchingView->header()->hide();
+	bookmarksView->header()->hide();
 	jumpToHelpSection(jumpToSection, jumpToFile );
-
-	QAccel *a = new QAccel( this, "a");
-	a->connectItem(a->insertItem(QAccel::stringToKey(tr("Ctrl+F"))), this, SLOT(find()));
-	a->connectItem(a->insertItem(QAccel::stringToKey(tr("F3"))), this, SLOT(findNext()));
+	readBookmarks();
+	readHistory();
+	splitter->setResizeMode( tabWidget, QSplitter::KeepSize );
+	splitter->setResizeMode( textBrowser, QSplitter::Stretch );
+	// reset previous size
+	prefs = PrefsManager::instance()->prefsFile->getPluginContext("helpbrowser");
+	int xsize = prefs->getUInt("xsize", 640);
+	int ysize = prefs->getUInt("ysize", 480);
+	resize(QSize(xsize, ysize).expandedTo(minimumSizeHint()) );
+	clearWState( WState_Polished );
 
 	connect( homeButton, SIGNAL( clicked() ), textBrowser, SLOT( home() ) );
 	connect( forwButton, SIGNAL( clicked() ), textBrowser, SLOT( forward() ) );
@@ -169,14 +364,49 @@ HelpBrowser::HelpBrowser( QWidget* parent, QString /*caption*/, QString guiLangu
 	connect( histMenu, SIGNAL(activated(int)), this, SLOT(histChosen(int)));
 	connect( listView, SIGNAL(clicked( QListViewItem *)), this, SLOT(itemSelected( QListViewItem *)));
 	// searching
-	connect( searchingEdit, SIGNAL(returnPressed()), this, SLOT(searchingButton_clicked()));
+	connect(searchingEdit, SIGNAL(returnPressed()), this, SLOT(searchingButton_clicked()));
 	connect(searchingView, SIGNAL(clicked( QListViewItem *)), this, SLOT(itemSearchSelected(QListViewItem *)));
 	connect(searchingButton, SIGNAL(clicked()), this, SLOT(searchingButton_clicked()));
+	// bookmarks
+	connect(bookmarkButton, SIGNAL(clicked()), this, SLOT(bookmarkButton_clicked()));
+	connect(deleteBookmarkButton, SIGNAL(clicked()), this, SLOT(deleteBookmarkButton_clicked()));
+	connect(deleteAllBookmarkButton, SIGNAL(clicked()), this, SLOT(deleteAllBookmarkButton_clicked()));
+	connect(bookmarksView, SIGNAL(clicked(QListViewItem *)), this, SLOT(itemBookmarkSelected(QListViewItem *)));
 }
 
 HelpBrowser::~HelpBrowser()
 {
 	// no need to delete child widgets, Qt does it all for us
+	// bookmarks
+	QFile bookFile(bookmarkFile());
+	if (bookFile.open(IO_WriteOnly))
+	{
+		QTextStream stream(&bookFile);
+		stream.setEncoding(QTextStream::UnicodeUTF8);
+		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+		stream << "<bookmarks>\n";
+		QListViewItemIterator it(bookmarksView);
+		for ( ; it.current(); ++it)
+			stream << "\t<item title=\"" << it.current()->text(0) << "\" url=\"" << it.current()->text(1) << "\" />\n";
+		stream << "</bookmarks>\n";
+		bookFile.close();
+	}
+	// history
+  	QFile histFile(historyFile());
+	if (histFile.open(IO_WriteOnly))
+	{
+		QTextStream stream(&histFile);
+		stream.setEncoding(QTextStream::UnicodeUTF8);
+		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+		stream << "<history>\n";
+		for (QMap<int,histd>::Iterator it = mHistory.begin() ; it != mHistory.end(); ++it)
+			stream << "\t<item title=\"" << it.data().title << "\" url=\"" << it.data().url << "\" />\n";
+		stream << "</history>\n";
+		histFile.close();
+	}
+	// size
+	prefs->set("xsize", width());
+	prefs->set("ysize", height());
 }
 
 void HelpBrowser::languageChange()
@@ -186,40 +416,13 @@ void HelpBrowser::languageChange()
 	listView->clear();
 
 	tabWidget->changeTab( tabContents, tr( "&Contents" ) );
-}
-
-
-void HelpBrowser::sourceChanged(const QString& url)
-{
-	bool inList = false;
-	struct histd his;
-	QString title = "";
-	title = textBrowser->documentTitle();
-	if (title == "")
-		title = url;
-	for (QMap<int, histd>::Iterator it = mHistory.begin(); it != mHistory.end(); ++it)
-	{
-		if (it.data().Title == title)
-			inList = true;
-	}
-	if (!inList)
-	{
-		his.Title = title;
-		his.Url = url;
-		mHistory[histMenu->insertItem(title)] = his;
-	}
-	if (mHistory.count() > 15)
-	{
-		int itk = histMenu->idAt(0);
-		mHistory.remove(itk);
-		histMenu->removeItem(itk);
-	}
+	QToolTip::add(searchingEdit, tr("Searching is case unsensitive"));
 }
 
 void HelpBrowser::histChosen(int i)
 {
 	if (mHistory.contains(i))
-		textBrowser->setSource(mHistory[i].Url);
+		textBrowser->setSource(mHistory[i].url);
 }
 
 void HelpBrowser::jumpToHelpSection(QString jumpToSection, QString jumpToFile)
@@ -227,11 +430,10 @@ void HelpBrowser::jumpToHelpSection(QString jumpToSection, QString jumpToFile)
 	QString toLoad;
 	bool noDocs=false;
 
-	if (jumpToFile=="")
+	if (jumpToFile.isEmpty())
 	{
-		QString pfad = DOCDIR;
-		toLoad = pfad + language + "/"; //clean this later to handle 5 char locales
-		if (jumpToSection=="")
+		toLoad = ScPaths::instance().docDir() + language + "/"; //clean this later to handle 5 char locales
+		if (jumpToSection.isEmpty())
 		{
 			if (listView->firstChild())
 			{
@@ -277,8 +479,7 @@ void HelpBrowser::loadHelp(QString filename)
 			toLoad=filename;
 		else
 		{
-			QString pfad = DOCDIR;
-			toLoad =  QDir::convertSeparators(pfad + "en/index.html");
+			toLoad = QDir::convertSeparators(ScPaths::instance().docDir() + "en/index.html");
 			language="en";
 			fi = QFileInfo(toLoad);
 			if (!fi.exists())
@@ -293,17 +494,23 @@ void HelpBrowser::loadHelp(QString filename)
 	if (Avail)
 	{
 		textBrowser->setSource(toLoad);
-		his.Title = textBrowser->documentTitle();
-		if (his.Title == "")
-			his.Title = toLoad;
-		his.Url = toLoad;
-		mHistory[histMenu->insertItem(his.Title)] = his;
+		his.title = textBrowser->documentTitle();
+		if (his.title.isEmpty())
+			his.title = toLoad;
+		his.url = toLoad;
+		mHistory[histMenu->insertItem(his.title)] = his;
+	}
+	if (mHistory.count() > 15)
+	{
+		int itk = histMenu->idAt(0);
+		mHistory.remove(itk);
+		histMenu->removeItem(itk);
 	}
 }
 
 void HelpBrowser::loadMenu()
 {
-	QString pfad = DOCDIR;
+	QString pfad = ScPaths::instance().docDir();
 	QString toLoad;
 	QString pfad2 = QDir::convertSeparators(pfad + language + "/menu.xml");
 	QFileInfo fi = QFileInfo(pfad2);
@@ -315,7 +522,7 @@ void HelpBrowser::loadMenu()
 		toLoad = QDir::convertSeparators(pfad + "en/menu.xml");
 		language="en";
 		fi = QFileInfo(toLoad);
-		qDebug("Scribus help in your selected language does not exist, trying English. Otherwise, please visit http://docs.scribus.net.");
+		sDebug("Scribus help in your selected language does not exist, trying English. Otherwise, please visit http://docs.scribus.net.");
 	}
 
 	if (fi.exists())
@@ -435,7 +642,7 @@ void HelpBrowser::loadMenu()
 		//scan for installed tutorials
 		if (haveTutorials)
 		{
-			QString path = DOCDIR;
+			QString path = ScPaths::instance().docDir();
 			path += language + "/tutorials/";
 			QDir dir(path, "*", QDir::Name, QDir::Dirs | QDir::NoSymLinks);
 
@@ -445,7 +652,7 @@ void HelpBrowser::loadMenu()
 				{
 					if (dir[i]!="." && dir[i]!="..")
 					{
-						QString tutorialdir = "tutorials/" + dir[i] + "/";
+						QString tutorialdir = QDir::convertSeparators("tutorials/" + dir[i] + "/");
 						QFileInfo file(QDir::convertSeparators(path + dir[i] + "/menu.xml"));
 						if (file.exists())  // menu.xml exists for tutorial
 						{
@@ -515,26 +722,33 @@ void HelpBrowser::itemSelected(QListViewItem *item)
 {
 	if ( !item )
 		return;
-	if (item->text(1)!=QString::null)
+	if (!item->text(1).isNull())
 	{
-		QString pfad = DOCDIR;
+		QString pfad = ScPaths::instance().docDir();
 		loadHelp(QDir::convertSeparators(pfad + language + "/" + item->text(1)));
 	}
 }
 
 void HelpBrowser::itemSearchSelected(QListViewItem *item)
 {
-	if (item && item->text(1) != QString::null)
+	if (item && !item->text(2).isNull())
 	{
-		loadHelp(item->text(1));
+		loadHelp(item->text(2));
 		findText = searchingEdit->text();
 		findNext();
 	}
 }
 
+void HelpBrowser::itemBookmarkSelected(QListViewItem *item)
+{
+	if (item && !item->text(1).isNull())
+		loadHelp(item->text(1));
+}
+
+
 void HelpBrowser::searchingInDirectory(QString aDir)
 {
-	QDir dir(aDir + "/");
+	QDir dir(QDir::convertSeparators(aDir + "/"));
 	QStringList lst = dir.entryList("*.html");
 	for (QStringList::Iterator it = lst.begin(); it != lst.end(); ++it)
 	{
@@ -550,10 +764,9 @@ void HelpBrowser::searchingInDirectory(QString aDir)
 				// the remove() hack is here for itemSelected() handling
 				QString fullname = fname;
 				QString title;
-				QListViewItem *refItem = listView->findItem(fname.remove(QDir::convertSeparators(QString(DOCDIR)+language+"/")), 1);
-
-				refItem ? title = refItem->text(0) : title = tr("unknown");
-				QListViewItem *item = new QListViewItem(searchingView, QString("%1x %2").arg(cnt).arg(title), fullname);
+				QListViewItem *refItem = listView->findItem(fname.remove(QDir::convertSeparators(ScPaths::instance().docDir()+language + "/")), 1);
+				title = refItem ? refItem->text(0) : fname;
+				HelpListItem *item = new HelpListItem(searchingView, QString("%2").arg(title), QString("%1").arg(cnt), fullname);
 				searchingView->insertItem(item);
 			}
 			f.close();
@@ -571,21 +784,21 @@ void HelpBrowser::searchingButton_clicked()
 	searchingView->clear();
 	// root files
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-	searchingInDirectory(QString(DOCDIR) + language + "/");
+	searchingInDirectory(QDir::convertSeparators(ScPaths::instance().docDir() + language + "/"));
 	QApplication::restoreOverrideCursor();
 }
 
 void HelpBrowser::find()
 {
-	findText = QInputDialog::getText(tr("Find"), tr("Search Term:"), QLineEdit::Normal, findText, 0, this);
-	if (findText == QString::null)
+	findText = QInputDialog::getText( tr("Find"), tr("Search Term:"), QLineEdit::Normal, findText, 0, this);
+	if (findText.isNull())
 		return;
 	findNext();
 }
 
 void HelpBrowser::findNext()
 {
-	if (findText == QString::null)
+	if (findText.isNull())
 	{
 		find();
 		return;
@@ -593,3 +806,96 @@ void HelpBrowser::findNext()
 	// find it. finally
 	textBrowser->find(findText, false, false, true, 0, 0);
 }
+
+void HelpBrowser::findPrevious()
+{
+	if (findText.isNull())
+	{
+		find();
+		return;
+	}
+	// find it. finally
+	textBrowser->find(findText, false, false, false, 0, 0);
+}
+
+void HelpBrowser::print()
+{
+	QPrinter printer;
+	printer.setFullPage(true);
+	if (!printer.setup(this))
+		return;
+
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	QPainter p(&printer);
+	QPaintDeviceMetrics metrics(p.device());
+	int dpix = metrics.logicalDpiX();
+	int dpiy = metrics.logicalDpiY();
+	const int margin = 72; // pt
+	QRect body(margin*dpix/72, margin*dpiy/72, metrics.width()-margin*dpix/72*2, metrics.height()-margin*dpiy/72*2);
+	QFont font("Helvetica");
+	QSimpleRichText richText( textBrowser->text(), font, textBrowser->context(), textBrowser->styleSheet(), textBrowser->mimeSourceFactory(), body.height());
+	richText.setWidth( &p, body.width());
+	QRect view(body);
+	int page = 1;
+	do {
+		richText.draw(&p, body.left(), body.top(), view, colorGroup());
+		view.moveBy(0, body.height());
+		p.translate(0 , -body.height());
+		p.setFont(font);
+		p.drawText(view.right() - p.fontMetrics().width(QString::number(page)), view.bottom() + p.fontMetrics().ascent() + 5, QString::number(page));
+		if (view.top()  >= body.top() + richText.height())
+			break;
+		printer.newPage();
+		page++;
+	} while (true);
+	QApplication::restoreOverrideCursor();
+}
+
+void HelpBrowser::bookmarkButton_clicked()
+{
+	QString title = textBrowser->documentTitle();
+	QString fname(QDir::cleanDirPath(textBrowser->source()));
+	title = QInputDialog::getText( tr("New Bookmark"), tr("New Bookmark's Title:"), QLineEdit::Normal, title, 0, this);
+	// user cancel
+	if (title.isNull())
+		return;
+	QListViewItem *item = new QListViewItem(bookmarksView, title, fname);
+	bookmarksView->insertItem(item);
+}
+
+void HelpBrowser::deleteBookmarkButton_clicked()
+{
+	delete(bookmarksView->currentItem());
+}
+
+void HelpBrowser::deleteAllBookmarkButton_clicked()
+{
+	bookmarksView->clear();
+}
+
+void HelpBrowser::readBookmarks()
+{
+	BookmarkParser handler;
+	handler.view = bookmarksView;
+	QFile xmlFile(bookmarkFile());
+	QXmlInputSource source(xmlFile);
+	QXmlSimpleReader reader;
+	reader.setContentHandler(&handler);
+	reader.parse(source);
+}
+
+void HelpBrowser::readHistory()
+{
+	HistoryParser handler;
+	handler.helpBrowser = this;
+	QFile xmlFile(historyFile());
+	QXmlInputSource source(xmlFile);
+	QXmlSimpleReader reader;
+	reader.setContentHandler(&handler);
+	reader.parse(source);
+}
+
+void HelpBrowser::setText(QString str)
+{
+	textBrowser->setText(str);
+}
