@@ -268,20 +268,23 @@ void SVGPlug::convert(int flags)
 	viewTransformY = 0;
 	viewScaleX = 1;
 	viewScaleY = 1;
-	haveViewBox = false;
 	if( !docElem.attribute( "viewBox" ).isEmpty() )
 	{
 		Conversion = 1.0;
 		double w2 = !docElem.attribute("width").isEmpty() ? parseUnit(docElem.attribute( "width" )) : 550.0;
 		double h2 = !docElem.attribute("height").isEmpty() ? parseUnit(docElem.attribute( "height" )) : 841.0;
 		Conversion = 0.8;
+		QWMatrix matrix;
+		addGraphicContext();
 		QString viewbox( docElem.attribute( "viewBox" ) );
 		QStringList points = QStringList::split( ' ', viewbox.replace( QRegExp(","), " ").simplifyWhiteSpace() );
 		viewTransformX = points[0].toDouble();
 		viewTransformY = points[1].toDouble();
 		viewScaleX = w2 / points[2].toDouble();
 		viewScaleY = h2 / points[3].toDouble();
-		haveViewBox = true;
+		matrix.translate(viewTransformX, viewTransformY);
+		matrix.scale(viewScaleX, viewScaleY);
+		m_gc.current()->matrix = matrix;
 	}
 	parseGroup( docElem );
 	currDoc->m_Selection->clear();
@@ -483,12 +486,12 @@ QPtrList<PageItem> SVGPlug::parseGroup(const QDomElement &e)
 			addGraphicContext();
 			SvgStyle *gc = m_gc.current();
 			parseStyle( gc, b );
-			z = currDoc->itemAdd(PageItem::Polygon, PageItem::Unspecified, BaseX, BaseY, 10, 10, gc->LWidth, gc->FillCol, gc->StrokeCol, true);
+			FPointArray pArray;
+			PageItem::ItemType itype = parseSVG(b.attribute("d"), &pArray) ? PageItem::PolyLine : PageItem::Polygon; 
+			z = currDoc->itemAdd(itype, PageItem::Unspecified, BaseX, BaseY, 10, 10, gc->LWidth, gc->FillCol, gc->StrokeCol, true);
 			PageItem* ite = currDoc->Items->at(z);
-			ite->fillRule = (gc->fillRule != "nonzero"); 
-			ite->PoLine.resize(0);
-			if (parseSVG( b.attribute( "d" ), &ite->PoLine ))
-				ite->convertTo(PageItem::PolyLine);
+			ite->fillRule = (gc->fillRule != "nonzero");
+			ite->PoLine = pArray;
 			if (ite->PoLine.size() < 4)
 			{
 				currDoc->m_Selection->addItem(ite);
@@ -545,10 +548,8 @@ QPtrList<PageItem> SVGPlug::parseGroup(const QDomElement &e)
 		{
 			addGraphicContext();
 			SvgStyle *gc = m_gc.current();
-			double x = b.attribute( "x" ).isEmpty() ? 0.0 : parseUnit(b.attribute("x"));
-			double y = b.attribute( "y" ).isEmpty() ? 0.0 : parseUnit(b.attribute("y"));
 			parseStyle(gc, b);
-			QPtrList<PageItem> el = parseText(x+BaseX, y+BaseY, b);
+			QPtrList<PageItem> el = parseText(b);
 			for (uint ec = 0; ec < el.count(); ++ec)
 			{
 				GElements.append(el.at(ec));
@@ -585,6 +586,9 @@ QPtrList<PageItem> SVGPlug::parseGroup(const QDomElement &e)
 			setupTransform( b );
 			SvgStyle *gc = m_gc.current();
 			PageItem* ite = currDoc->Items->at(z);
+			QWMatrix gcm = gc->matrix;
+			double coeff1 = sqrt(gcm.m11() * gcm.m11() + gcm.m12() * gcm.m12());
+			double coeff2 = sqrt(gcm.m21() * gcm.m21() + gcm.m22() * gcm.m22());
 			switch (ite->itemType())
 			{
 			case PageItem::ImageFrame:
@@ -592,7 +596,7 @@ QPtrList<PageItem> SVGPlug::parseGroup(const QDomElement &e)
 					QWMatrix mm = gc->matrix;
 					ite->moveBy(mm.dx(), mm.dy());
 					ite->setWidthHeight(ite->width() * mm.m11(), ite->height() * mm.m22());
-					ite->setLineWidth(ite->lineWidth() * ((mm.m11() + mm.m22()) / 2.0));
+					ite->setLineWidth(ite->lineWidth() * (coeff1 + coeff2) / 2.0);
 					if (ite->PicAvail)
 						ite->setImageXYScale(ite->width() / ite->pixm.width(), ite->height() / ite->pixm.height());
 					break;
@@ -600,7 +604,7 @@ QPtrList<PageItem> SVGPlug::parseGroup(const QDomElement &e)
 			case PageItem::TextFrame:
 				{
 					QWMatrix mm = gc->matrix;
-					ite->setLineWidth(ite->lineWidth() * ((mm.m11() + mm.m22()) / 2.0));
+					ite->setLineWidth(ite->lineWidth() * (coeff1 + coeff2) / 2.0);
 				}
 				break;
 			default:
@@ -609,14 +613,14 @@ QPtrList<PageItem> SVGPlug::parseGroup(const QDomElement &e)
 					ite->FrameType = 3;
 					QWMatrix mm = gc->matrix;
 					ite->PoLine.map(mm);
-					if (haveViewBox)
+					/*if (haveViewBox)
 					{
 						QWMatrix mv;
 						mv.translate(viewTransformX, viewTransformY);
 						mv.scale(viewScaleX, viewScaleY);
 						ite->PoLine.map(mv);
-					}
-					ite->setLineWidth(ite->lineWidth() * ((mm.m11() + mm.m22()) / 2.0));
+					}*/
+					ite->setLineWidth(ite->lineWidth() * (coeff1 + coeff2) / 2.0);
 					FPoint wh = getMaxClipF(&ite->PoLine);
 					ite->setWidthHeight(wh.x(), wh.y());
 					ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
@@ -784,7 +788,7 @@ QWMatrix SVGPlug::parseTransform( const QString &transform )
 				result.setMatrix(sx, params[1].toDouble(), params[2].toDouble(), sy, params[4].toDouble() * Conversion, params[5].toDouble() * Conversion);
 			}
 		}
-		ret = ret * result;
+		ret = result * ret;
 	}
 	return ret;
 }
@@ -1535,6 +1539,8 @@ void SVGPlug::parsePA( SvgStyle *obj, const QString &command, const QString &par
 	}
 	else if( command == "font-size" )
 		obj->FontSize = static_cast<int>(parseUnit(params) * 10.0);
+	else if( command == "text-anchor" )
+		obj->textAnchor = params;
 	else
 		unsupported = true;
 }
@@ -1579,6 +1585,8 @@ void SVGPlug::parseStyle( SvgStyle *obj, const QDomElement &e )
 		parsePA( obj, "font-family", e.attribute( "font-family" ) );
 	if( !e.attribute( "font-size" ).isEmpty() )
 		parsePA( obj, "font-size", e.attribute( "font-size" ) );
+	if( !e.attribute( "text-anchor" ).isEmpty() )
+		parsePA( obj, "text-anchor", e.attribute( "text-anchor" ) );
 	QString style = e.attribute( "style" ).simplifyWhiteSpace();
 	QStringList substyles = QStringList::split( ';', style );
 	for( QStringList::Iterator it = substyles.begin(); it != substyles.end(); ++it )
@@ -1754,235 +1762,209 @@ void SVGPlug::parseGradient( const QDomElement &e )
 	m_gradients.insert(e.attribute("id"), gradhelper);
 }
 
-QPtrList<PageItem> SVGPlug::parseText(double x, double y, const QDomElement &e)
+QPtrList<PageItem> SVGPlug::parseText(const QDomElement &e)
 {
-	ScText *hg;
-	QPainter p;
 	QPtrList<PageItem> GElements;
-	p.begin(ScMW->view->viewport());
-//	QFont ff(currDoc->UsedFonts[m_gc.current()->Family]);
-	QFont ff(m_gc.current()->Family);
-	ff.setPointSize(QMAX(qRound(m_gc.current()->FontSize / 10.0), 1));
-	p.setFont(ff);
 	setupTransform(e);
-	int desc = p.fontMetrics().descent();
-	int asce = p.fontMetrics().ascent();
+	QDomNode c = e.firstChild();
 	double BaseX = currDoc->currentPage->xOffset();
 	double BaseY = currDoc->currentPage->yOffset();
-	QString Text = QString::fromUtf8(e.text()).stripWhiteSpace();
-	QDomNode c = e.firstChild();
+	double x = e.attribute( "x" ).isEmpty() ? 0.0 : parseUnit(e.attribute("x"));
+	double y = e.attribute( "y" ).isEmpty() ? 0.0 : parseUnit(e.attribute("y"));
 	if ((!c.isNull()) && (c.toElement().tagName() == "tspan"))
 	{
-		double tempW = 0;
 		for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 		{
-			tempW = 0;
 			QDomElement tspan = n.toElement();
 			addGraphicContext();
 			SvgStyle *gc = m_gc.current();
 			parseStyle(gc, tspan);
-			//int z = ScMW->view->PaintText(x, y, 10, 10, gc->LWidth, gc->FillCol);
-			int z = currDoc->itemAdd(PageItem::TextFrame, PageItem::Unspecified, x, y, 10, 10, gc->LWidth, CommonStrings::None, gc->FillCol, true);
-			PageItem* ite = currDoc->Items->at(z);
-			ite->setTextToFrameDist(0.0, 0.0, 0.0, 0.0);
-			ite->setLineSpacing(gc->FontSize / 10.0 + 2);
-			ite->setHeight(ite->lineSpacing()+desc+2);
-			ScMW->SetNewFont(gc->Family);
-			QWMatrix mm = gc->matrix;
-			if( (!tspan.attribute("x").isEmpty()) && (!tspan.attribute("y").isEmpty()) )
+			if (!gc->Display)
+				continue;
+			QPtrList<PageItem> el = parseTextElement(x, y, tspan);
+			for (uint ec = 0; ec < el.count(); ++ec)
 			{
-				double x1 = parseUnit( tspan.attribute( "x", "0" ) );
-				double y1 = parseUnit( tspan.attribute( "y", "0" ) );
-				double mx = mm.m11() * x1 + mm.m21() * y1 + mm.dx();
-				double my = mm.m22() * y1 + mm.m12() * x1 + mm.dy();
-				ite->setXPos(mx + BaseX);
-				ite->setYPos(my + BaseY);
+				GElements.append(el.at(ec));
+				Elements.append(el.at(ec));
 			}
-			else
-			{
-				double mx = mm.m11() * x + mm.m21() * y + mm.dx();
-				double my = mm.m22() * y + mm.m12() * x + mm.dy();
-				ite->setXPos(mx);
-				ite->setYPos(my);
-			}
-			if (!tspan.text().isNull())
-				Text = QString::fromUtf8(tspan.text()).stripWhiteSpace();
-			else
-				Text = " ";
-			ite->setFont(gc->Family);
-			ite->TxtFill = gc->FillCol;
-			ite->ShTxtFill = 100;
-			ite->TxtStroke = gc->StrokeCol;
-			ite->ShTxtStroke = 100;
-			ite->setFontSize(gc->FontSize);
-			ite->TxTStyle = 0;
-			ite->TxtScale = 1000;
-			ite->TxtScaleV = 1000;
-			ite->TxtBase = 0;
-			ite->TxtShadowX = 50;
-			ite->TxtShadowY = -50;
-			ite->TxtOutline = 10;
-			ite->TxtUnderPos = -1;
-			ite->TxtUnderWidth = -1;
-			ite->TxtStrikePos = -1;
-			ite->TxtStrikeWidth = -1;
-			for (uint tt = 0; tt < Text.length(); ++tt)
-			{
-				hg = new ScText;
-				hg->ch = Text.at(tt);
-				hg->cfont = (*currDoc->AllFonts)[gc->Family];
-				hg->csize = gc->FontSize;
-				hg->ccolor = gc->FillCol;
-				hg->cextra = 0;
-				hg->cshade = 100;
-				hg->cstroke = gc->StrokeCol;
-				hg->cshade2 = 100;
-				hg->cscale = 1000;
-				hg->cscalev = 1000;
-				hg->cbase = 0;
-				hg->cshadowx = 50;
-				hg->cshadowy = -50;
-				hg->coutline = 10;
-				hg->cunderpos = -1;
-				hg->cunderwidth = -1;
-				hg->cstrikepos = -1;
-				hg->cstrikewidth = -1;
-				hg->cselect = false;
-				if( !tspan.attribute( "stroke" ).isEmpty() )
-					hg->cstyle = 4;
-				else
-					hg->cstyle = 0;
-				hg->cab = 0;
-				hg->xp = 0;
-				hg->yp = 0;
-				hg->PRot = 0;
-				hg->PtransX = 0;
-				hg->PtransY = 0;
-				hg->cembedded = 0;
-				ite->itemText.append(hg);
-				tempW += RealCWidth(currDoc, hg->cfont, hg->ch, hg->csize)+1;
-				if (hg->ch == QChar(13))
-				{
-					ite->setWidthHeight(QMAX(ite->width(), tempW), ite->height() + ite->lineSpacing()+desc);
-					tempW = 0;
-				}
-			}
-			ite->setWidth(QMAX(ite->width(), tempW));
-			ite->SetRectFrame();
-			currDoc->setRedrawBounding(ite);
-			ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
-			currDoc->m_Selection->addItem(ite);
-			ScMW->view->frameResizeHandle = 1;
-			ScMW->view->setGroupRect();
-			ScMW->view->scaleGroup(mm.m11(), mm.m22());
-			ScMW->view->Deselect();
-			ite->moveBy(0.0, -asce * mm.m22());
-			if( !e.attribute("id").isEmpty() )
-				ite->setItemName(" "+e.attribute("id"));
-			ite->setFillTransparency( 1 - gc->FillOpacity * gc->Opacity);
-			ite->setLineTransparency( 1 - gc->StrokeOpacity * gc->Opacity);
-			ite->PLineEnd = gc->PLineEnd;
-			ite->PLineJoin = gc->PLineJoin;
-			ite->setTextFlowsAroundFrame(false);
-			ite->DashOffset = gc->dashOffset;
-			ite->DashValues = gc->dashArray;
-			/*			if (gc->Gradient != 0)
-						{
-							ite->fill_gradient = gc->GradCo;
-							ScMW->view->SelItem.append(ite);
-							ScMW->view->ItemGradFill(gc->Gradient, gc->GCol2, 100, gc->GCol1, 100);
-							ScMW->view->SelItem.clear();
-						} */
-			GElements.append(ite);
-			Elements.append(ite);
 			delete( m_gc.pop() );
 		}
 	}
 	else
 	{
 		SvgStyle *gc = m_gc.current();
-		//int z = ScMW->view->PaintText(x, y - qRound(gc->FontSize / 10.0), 10, 10, gc->LWidth, gc->FillCol);
-		int z = currDoc->itemAdd(PageItem::TextFrame, PageItem::Unspecified, x, y - qRound(gc->FontSize / 10.0), 10, 10, gc->LWidth, CommonStrings::None, gc->FillCol, true);
-		PageItem* ite = currDoc->Items->at(z);
-		ite->setTextToFrameDist(0.0, 0.0, 0.0, 0.0);
-		ite->setLineSpacing(gc->FontSize / 10.0 + 2);
-		ScMW->SetNewFont(gc->Family);
-		ite->setFont(gc->Family);
-		ite->TxtFill = gc->FillCol;
-		ite->ShTxtFill = 100;
-		ite->TxtStroke = gc->StrokeCol;
-		ite->ShTxtStroke = 100;
-		ite->setFontSize(gc->FontSize);
-		ite->TxTStyle = 0;
-		ite->TxtScale = 1000;
-		ite->TxtScaleV = 1000;
-		ite->TxtBase = 0;
-		ite->TxtShadowX = 50;
-		ite->TxtShadowY = -50;
-		ite->TxtOutline = 10;
-		ite->TxtUnderPos = -1;
-		ite->TxtUnderWidth = -1;
-		ite->TxtStrikePos = -1;
-		ite->TxtStrikeWidth = -1;
-		for (uint cc = 0; cc<Text.length(); ++cc)
+		QPtrList<PageItem> el = parseTextElement(x, y, e);
+		for (uint ec = 0; ec < el.count(); ++ec)
 		{
-			hg = new ScText;
-			hg->ch = Text.at(cc);
-			hg->cfont = (*currDoc->AllFonts)[gc->Family];
-			hg->csize = gc->FontSize;
-			hg->ccolor = gc->FillCol;
-			hg->cextra = 0;
-			hg->cshade = 100;
-			hg->cstroke = gc->StrokeCol;
-			hg->cshade2 = 100;
-			hg->cscalev = 1000;
-			hg->cscale = 1000;
-			hg->cbase = 0;
-			hg->cshadowx = 50;
-			hg->cshadowy = -50;
-			hg->coutline = 10;
-			hg->cunderpos = -1;
-			hg->cunderwidth = -1;
-			hg->cstrikepos = -1;
-			hg->cstrikewidth = -1;
-			hg->cselect = false;
-			if( !e.attribute( "stroke" ).isEmpty() )
-				hg->cstyle = 4;
-			else
-				hg->cstyle = 0;
-			hg->cab = 0;
-			hg->xp = 0;
-			hg->yp = 0;
-			hg->PRot = 0;
-			hg->PtransX = 0;
-			hg->PtransY = 0;
-			hg->cembedded = 0;
-			ite->itemText.append(hg);
-			ite->setWidth(ite->width() + RealCWidth(currDoc, hg->cfont, hg->ch, hg->csize)+1);
-			ite->setHeight(ite->lineSpacing()+desc+2);
+			GElements.append(el.at(ec));
+			Elements.append(el.at(ec));
 		}
-		ite->SetRectFrame();
-		currDoc->setRedrawBounding(ite);
-		if( !e.attribute("id").isEmpty() )
-			ite->setItemName(" "+e.attribute("id"));
-		ite->setFillTransparency( 1 - gc->FillOpacity * gc->Opacity);
-		ite->setLineTransparency( 1 - gc->StrokeOpacity * gc->Opacity);
-		ite->PLineEnd = gc->PLineEnd;
-		ite->PLineJoin = gc->PLineJoin;
-		ite->setTextFlowsAroundFrame(false);
-		ite->DashOffset = gc->dashOffset;
-		ite->DashValues = gc->dashArray;
-		/*		if (gc->Gradient != 0)
-				{
-					ite->fill_gradient = gc->GradCo;
-					ScMW->view->SelItem.append(ite);
-					ScMW->view->ItemGradFill(gc->Gradient, gc->GCol2, 100, gc->GCol1, 100);
-					ScMW->view->SelItem.clear();
-				} */
-		GElements.append(ite);
-		Elements.append(ite);
 	}
-	p.end();
+	return GElements;
+}
+
+QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomElement &e)
+{
+	ScText *hg;
+	QPtrList<PageItem> GElements;
+	QFont ff(m_gc.current()->Family);
+	ff.setPointSize(QMAX(qRound(m_gc.current()->FontSize / 10.0), 1));
+	QFontMetrics fontMetrics(ff);
+	int desc = fontMetrics.descent();
+	double BaseX = currDoc->currentPage->xOffset();
+	double BaseY = currDoc->currentPage->yOffset();
+	QString Text = QString::fromUtf8(e.text()).stripWhiteSpace();
+	QDomNode c = e.firstChild();
+	if ( e.tagName() == "tspan" && e.text().isNull() )
+			Text = " ";
+	
+	double maxWidth = 0, maxHeight = 0;
+	double tempW = 0, tempH = 0;
+	SvgStyle *gc = m_gc.current();
+	int ity = (e.tagName() == "tspan") ? y : (y - qRound(gc->FontSize / 10.0));
+	int z = currDoc->itemAdd(PageItem::TextFrame, PageItem::Unspecified, x, ity, 10, 10, gc->LWidth, CommonStrings::None, gc->FillCol, true);
+	PageItem* ite = currDoc->Items->at(z);
+	ite->setTextToFrameDist(0.0, 0.0, 0.0, 0.0);
+	ite->setLineSpacing(gc->FontSize / 10.0 + 2);
+	ite->setHeight(ite->lineSpacing()+desc+2);
+	ScMW->SetNewFont(gc->Family);
+	QWMatrix mm = gc->matrix;
+	double scalex = sqrt(mm.m11() * mm.m11() + mm.m12() * mm.m12());
+	double scaley = sqrt(mm.m21() * mm.m21() + mm.m22() * mm.m22());
+	if( (!e.attribute("x").isEmpty()) && (!e.attribute("y").isEmpty()) )
+	{
+		double x1 = parseUnit( e.attribute( "x", "0" ) );
+		double y1 = parseUnit( e.attribute( "y", "0" ) );
+		double mx = mm.m11() * x1 + mm.m21() * y1 + mm.dx();
+		double my = mm.m12() * x1 + mm.m22() * y1 + mm.dy();
+		ite->setXPos(mx + BaseX);
+		ite->setYPos(my + BaseY);
+	}
+	else
+	{
+		double mx = mm.m11() * x + mm.m21() * y + mm.dx();
+		double my = mm.m12() * x + mm.m22() * y + mm.dy();
+		ite->setXPos(mx + BaseX);
+		ite->setYPos(my + BaseY);
+	}
+	ite->setFont(gc->Family);
+	ite->setFillColor(CommonStrings::None);
+	ite->setLineColor(CommonStrings::None);
+	ite->TxtFill = gc->FillCol;
+	ite->ShTxtFill = 100;
+	ite->TxtStroke = gc->StrokeCol;
+	ite->ShTxtStroke = 100;
+	ite->setFontSize(gc->FontSize);
+	ite->TxTStyle = 0;
+	ite->TxtScale = 1000;
+	ite->TxtScaleV = 1000;
+	ite->TxtBase = 0;
+	ite->TxtShadowX = 50;
+	ite->TxtShadowY = -50;
+	ite->TxtOutline = 10;
+	ite->TxtUnderPos = -1;
+	ite->TxtUnderWidth = -1;
+	ite->TxtStrikePos = -1;
+	ite->TxtStrikeWidth = -1;
+	for (uint tt = 0; tt < Text.length(); ++tt)
+	{
+		hg = new ScText;
+		hg->ch = Text.at(tt);
+		hg->cfont = (*currDoc->AllFonts)[gc->Family];
+		hg->csize = gc->FontSize;
+		hg->ccolor = gc->FillCol;
+		hg->cextra = 0;
+		hg->cshade = 100;
+		hg->cstroke = gc->StrokeCol;
+		hg->cshade2 = 100;
+		hg->cscale = 1000;
+		hg->cscalev = 1000;
+		hg->cbase = 0;
+		hg->cshadowx = 50;
+		hg->cshadowy = -50;
+		hg->coutline = 10;
+		hg->cunderpos = -1;
+		hg->cunderwidth = -1;
+		hg->cstrikepos = -1;
+		hg->cstrikewidth = -1;
+		hg->cselect = false;
+		if( !e.attribute( "stroke" ).isEmpty() )
+			hg->cstyle = 4;
+		else
+			hg->cstyle = 0;
+		hg->cab = 0;
+		hg->xp = 0;
+		hg->yp = 0;
+		hg->PRot = 0;
+		hg->PtransX = 0;
+		hg->PtransY = 0;
+		hg->cembedded = 0;
+		ite->itemText.append(hg);
+		tempW += RealCWidth(currDoc, hg->cfont, hg->ch, hg->csize)+1;
+		tempH  = RealCHeight(currDoc, hg->cfont, hg->ch, hg->csize)+1;
+		maxWidth  = (tempW > maxWidth) ? tempW : maxWidth;
+		maxHeight = (tempH > maxHeight) ? tempH : maxHeight;
+		if (hg->ch == QChar(13))
+		{
+			ite->setWidthHeight(QMAX(ite->width(), tempW), ite->height() + ite->lineSpacing()+desc);
+			tempW = 0;
+		}
+	}
+	double xpos = ite->xPos();
+	double ypos = ite->yPos();
+	ite->setWidthHeight(QMAX(ite->width(), maxWidth), QMAX(ite->height(), maxHeight));
+	double xoffset = 0.0, yoffset = 0.0;
+	if( gc->textAnchor == "middle" )
+	{
+		currDoc->currentParaStyle = 1;
+		currDoc->chAbStyle(ite, 1);
+		xoffset = -ite->width() / 2;
+	}
+	else if( gc->textAnchor == "end")
+	{
+		currDoc->currentParaStyle = 2;
+		currDoc->chAbStyle(ite, 2);
+		xoffset = -ite->width();
+	}
+	double rotation = getRotationFromMatrix(gc->matrix, 0.0);
+	if (rotation != 0.0)
+	{
+		double temp = xoffset;
+		xoffset = cos(-rotation) * temp;
+		yoffset = sin(-rotation) * temp;
+	}
+	ite->setXPos(xpos + xoffset);
+	ite->setYPos(ypos + yoffset);
+	ite->setRotation(-rotation * 180 / M_PI);
+	ite->SetRectFrame();
+	currDoc->setRedrawBounding(ite);
+	ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
+	currDoc->m_Selection->addItem(ite);
+	ScMW->view->frameResizeHandle = 1;
+	ScMW->view->setGroupRect();
+	ScMW->view->scaleGroup(scalex, scaley);
+	// scaleGroup scale may modify position... weird...
+	ite->setXYPos(xpos + xoffset, ypos + yoffset);
+	ScMW->view->Deselect();
+	// Probably some scalex and scaley to add somewhere
+	ite->moveBy(maxHeight * sin(-rotation) * scaley, -maxHeight * cos(-rotation) * scaley);
+	if( !e.attribute("id").isEmpty() )
+		ite->setItemName(" "+e.attribute("id"));
+	ite->setFillTransparency( 1 - gc->FillOpacity * gc->Opacity);
+	ite->setLineTransparency( 1 - gc->StrokeOpacity * gc->Opacity);
+	ite->PLineEnd = gc->PLineEnd;
+	ite->PLineJoin = gc->PLineJoin;
+	ite->setTextFlowsAroundFrame(false);
+	ite->DashOffset = gc->dashOffset;
+	ite->DashValues = gc->dashArray;
+	//if (gc->Gradient != 0)
+	//{
+	//	ite->fill_gradient = gc->GradCo;
+	//	ScMW->view->SelItem.append(ite);
+	//	ScMW->view->ItemGradFill(gc->Gradient, gc->GCol2, 100, gc->GCol1, 100);
+	//	ScMW->view->SelItem.clear();
+	//} 
+	GElements.append(ite);
 	return GElements;
 }
 
