@@ -714,15 +714,16 @@ public: // Public attributes
 	cmsHPROFILE DocInputProf;
 	cmsHPROFILE DocOutputProf;
 	cmsHPROFILE DocPrinterProf;
-	cmsHTRANSFORM stdTrans;
-	cmsHTRANSFORM stdProof;
+	cmsHTRANSFORM stdTransCMYK2Mon;
+	cmsHTRANSFORM stdTransRGBDoc2Mon;
+	cmsHTRANSFORM stdTransRGBDoc2CMYK;
+	cmsHTRANSFORM stdTransCMYK2RGBDoc;
+	cmsHTRANSFORM stdProofRGB;
+	cmsHTRANSFORM stdProofRGBGC;
+	cmsHTRANSFORM stdProofCMYK;
+	cmsHTRANSFORM stdProofCMYKGC;
 	cmsHTRANSFORM stdTransImg;
 	cmsHTRANSFORM stdProofImg;
-	cmsHTRANSFORM stdTransCMYK;
-	cmsHTRANSFORM stdProofCMYK;
-	cmsHTRANSFORM stdTransRGB;
-	cmsHTRANSFORM stdProofGC;
-	cmsHTRANSFORM stdProofCMYKGC;
 	bool SoftProofing;
 	bool Gamut;
 	int IntentMonitor;
@@ -812,7 +813,8 @@ public slots:
 	void itemSelection_TogglePrintEnabled();
 	void itemSelection_ChangePreviewResolution(int id);
 	void itemSelection_ClearItem(Selection* customSelection=0);
-	void itemSelection_DeleteItem(Selection* customSelection=0);
+	//! Delete the items in the current selection. When force is true, we do not warn the user and make SE happy too. Force is used from @sa Page::restorePageItemCreation
+	void itemSelection_DeleteItem(Selection* customSelection=0, bool forceDeletion = false);
 	void itemSelection_SetItemFillTransparency(double t);
 	void itemSelection_SetItemLineTransparency(double t);
 	void itemSelection_FlipH();
